function m0203
%  m0203.m     (Matlab&Simulink Rel.13 SP1)
%
%  Bild 2.3
%  Mann/Schiffelgen/Froriep,
%  Einfhrung in die Regelungstechnik, 
%  10.Aufl., Hanser-Verlag, Mnchen, 2005
%  ISBN 3-446-40303-5
%
%  Unterprogramme: s0203.mdl
%
%  (c) 10.11.05  R.Froriep
%
%
% ########################################################
%
%  Variations-Empfehlungen:
%       ue       -5 < ue < 5  (V)
%                Vektor mit konstanten Werten der 
%                Eingangsspannung ue, fr die die Schaltung
%                der Reihe nach simuliert wird 
%
%       umax     in V
%                berhitzungsgrenze (Leitung unterbrochen)
%
% ########################################################
clear
%  Eingabefeld mit Angabe der Voreinstellungen  

     ue=[1:1:4 -1:-1:-3];     %   ue=[1:1:4 -1:-1:-3];        
     
     umax=3.5;                %   umax=3.5

% ########################################################

menu='none';  % none oder fig
close all

% RC-Netzwerk Daten:
R=1 ;         % KOhm
C=100;        % uF

% Umrechnung auf SI-Einheiten
R=R*1e3;
C=C*1e-6;

T1=R*C;


te=.8;

% In Base-Workspace fr Simulink
assignin('base','T1',T1)

figure(1)
set(gcf,'Units','normal','Position',[.4 .55 .5 .2], ...
    'NumberTitle','off','MenuBar',menu,...
    'Name',' Bild 2.3');
buch(gcf)

sp1=subplot(1,2,1);
xachs1=[0 te]; xachs2=[0 0];
plot(xachs1,xachs2,'k')
set(gca,...
    'Position',[.13 .22 .35 .7],...
    'XLim',[0 te],'XTick',[],...
    'YLim',[-5 5],'YTick',[-5:5:5],...
    'Box','on',...
    'NextPlot','add');
xlabel('\itt  \rightarrow')
ylabel('\itu_{\rme} \rightarrow')
grid on

sp2=subplot(1,2,2);
xachs1=[0 te]; xachs2=[0 0];
plot(xachs1,xachs2,'k')
set(gca,...
    'Position',[.59 .22 .35 .7],...
    'XLim',[0 te],'XTick',[],...
    'YLim',[-5 5],'YTick',[-5:5:5],...
    'Box','on',...
    'NextPlot','add');
xlabel('\itt \rightarrow')
ylabel('\itu_{\rmC} \rightarrow')
grid on

% Startwerte fr die for-Schleife
pause(.8)

Anzahl=size(ue,2);
for i=1:Anzahl    % Sprungantworten

    uedach=ue(i);

    assignin('base','uedach',uedach)
    opts=simset('Solver','ode45',...
        'InitialState',[],...
        'MaxStep',.01);
    [t,x,y]=sim('s0203',[0 te],opts);

    if i==1
        axes(sp1)
        plot(t,y(:,1),'k','linewidth',2)
        axes(sp2)
        plot(t,y(:,2),'k','linewidth',2)
    end


    axes(sp1)
    plot(t,y(:,1),'k','linewidth',1)

    axes(sp2)
    for j=1:size(y,1)           % berlauf
        if abs(y(j,2))>umax
            y(j,2)=0;
        end
    end
    plot(t,y(:,2),'k','linewidth',1)

    pause(1)

end

















function []=buch(fighandle)
cr0=uimenu('parent', fighandle);
set(cr0,'Label','?')
cr1=uimenu('parent', cr0);
set(cr1,'Label','Mann/Schiffelgen/Froriep')
cr2=uimenu('parent', cr0);
set(cr2,'Label','Einfhrung in die Regelungstechnik')
cr3=uimenu('parent', cr0);
set(cr3,'Label','Hanser-Verlag')

