function m0205
%  m0205.m     (Matlab&Simulink Rel.13 SP1)
%
%  Bild 2.5
%  Mann/Schiffelgen/Froriep,
%  Einfhrung in die Regelungstechnik, 
%  10.Aufl., Hanser-Verlag, Mnchen, 2005
%  ISBN 3-446-40303-5
%
%  Unterprogramme: s0205.mdl
%
%  (c) 10.11.05  R.Froriep
%
% ########################################################
%
%  Variations-Empfehlungen:
%
%  tV       tV > 0         
%           Zeitspanne bis zu einer weiteren Messung an
%           der Schaltung. 
%
%           Ab welchem tV-Wert ndert sich das 
%           bertragungsverhalten? (ab dann kann Zeit-
%           invarianz nicht mehr angenommen werden bzw.
%           das Verschiebungsprinzip ist nicht mehr erfllt.)
%
% ########################################################
clear
%  Eingabefeld mit Angabe der Voreinstellungen  

     tV =0.5;                    % tV=.5
     
% ########################################################

menu='none';  % none oder fig
close all

% RC-Netzwerk Daten:
R=1 ;         % KOhm
C=100;        % uF

% Umrechnung auf SI-Einheiten
R=R*1e3;
C=C*1e-6;

T1=R*C;
t0=.2;
te=2;
uedach=1;

% Fr Simulink
assignin('base','T1',T1)
assignin('base','uedach',uedach)

figure(1)
set(gcf,'Units','normal','Position',[.45 .65 .5 .25], ...
    'NumberTitle','off','MenuBar',menu,...
    'Name',' Bild 2.5');
buch(gcf)

sp1=subplot(1,2,1);
set(gca,...
    'Position',[.12 .2 .35 .7],...
    'XLim',[0 te],'XTick',[0:te:te],...
    'YLim',[-.5 1.5],'YTick',[],...
    'Box','on',...
    'NextPlot','add');
xachs1=[0 te]; xachs2=[0 0];
yachs1=[0 0]; yachs2=[-1 2];
plot(xachs1,xachs2,'k',yachs1,yachs2,'k')
xlabel('\itt \rightarrow')
ylabel('\itu_{\rme} \rightarrow')
grid on

sp2=subplot(1,2,2);
set(gca,...
    'Position',[.57 .2 .35 .7],...
    'XLim',[0 te],'XTick',[0:te:te],...
    'YLim',[-.5 1.5],'YTick',[],...
    'Box','on',...
    'NextPlot','add');
xachs1=[0 te]; xachs2=[0 0];
yachs1=[0 0]; yachs2=[-1 2];
plot(xachs1,xachs2,'k',yachs1,yachs2,'k')
xlabel('\itt \rightarrow')
ylabel('\itu_{\rmC} \rightarrow')
grid on


for i=1:2

    if i==1, tstep=t0;    line='k-';  end
    if i==2, tstep=t0+tV; line='k--';  end
    assignin('base','tstep',tstep)

    if (i==2)&(tV>1)
        T1=3*T1;
    end
    assignin('base','T1',T1)

    opts=simset('Solver','ode45',...
        'InitialState',[],...
        'MaxStep',0.05);

    [t,x,y]=sim('s0205',[0 te],opts);

    axes(sp1);  % axes zu current axes machen
    plot(t,y(:,1),line,'linewidth',1.5)
    axes(sp2);
    plot(t,y(:,2),line,'linewidth',1.5)

    pause(1)
end





















function []=buch(fighandle)
cr0=uimenu('parent', fighandle);
set(cr0,'Label','?')
cr1=uimenu('parent', cr0);
set(cr1,'Label','Mann/Schiffelgen/Froriep')
cr2=uimenu('parent', cr0);
set(cr2,'Label','Einfhrung in die Regelungstechnik')
cr3=uimenu('parent', cr0);
set(cr3,'Label','Hanser-Verlag')

