function m0310
%  m0310.m     (Matlab&Simulink Rel.13 SP1)
%
%  Bild 3.10 
%  Mann/Schiffelgen/Froriep,
%  Einfhrung in die Regelungstechnik, 
%  10.Aufl., Hanser-Verlag, Mnchen, 2005
%  ISBN 3-446-40303-5
%
%  Unterprogramme: s0310.mdl
%
%  (c)10.11.05  R.Froriep
%
% ########################################################
%
%  Variations-Empfehlungen:
%
%  uAdach   Sprunghhe Ankerspannung in V
%           im Bereich  0 < uAdach < 45 
%
%  MLdach   Sprunghhe Lastmoment in Nm
%           im Bereich  0 < MLdach < 450 
%
% ########################################################
clear

   uAdach=40;     % uAdach=20;
   
   MLdach=300;    % MLdach=300


% ########################################################

menu='none';  % none oder fig
close all
fonts=8;


% Streckendaten:
c2=200;   %  magn.Flu*Stromstrke-->Moment (Nm/(Wb*A))
c3=.2;    %  magn.Flu*Drehzahl-->EMK-Spannung (V/(Wb*rad/s))
J=200;    %  Trgheitsmoment von Anker und Last (Nm/(rad/s^2))
Phi=1;    %  magn. Flu  (Wb=Vs)
Ra=1;     %  ohmscher Widerstand im Ankerkreis (Ohm)
%La=1;    %  Induktivitt im Ankerkreis (Ohm*s)

T1=J*Ra/(c2*c3*Phi^2);
Kp=1/(c3*Phi);
Kpz=-Ra/(c2*c3*Phi^2);

% Signaldaten
% AP:
ML0=0;             % in Nm    (mittleres Lastmoment)
wS=0;              % in rad/s  (Solldrehzahl)
uA0=1/Kp*(wS-Kpz*ML0);  % in V  (zugehrige Ankerspannung)

% Sprunghhen
%uAdach=20;    % Sprunghhe in V
%MLdach=400;    % Sprunghhe in V


% Fr Simulink
assignin('base','uAdach',uAdach)
assignin('base','MLdach',MLdach)
assignin('base','ML0',ML0)
assignin('base','wS',wS)
assignin('base','uA0',uA0)
assignin('base','T1',T1)
assignin('base','Kp',Kp)
assignin('base','Kpz',Kpz)


% Integrationsschleife:
te=25;

figure(1)
set(gcf,'Units','normal','Position',[.45 .1 .5 .75], ...
    'NumberTitle','off','MenuBar',menu,...
    'Name',' Bild 3.10  Gleichstrommotor');
buch(gcf)


sp311=subplot(3,1,1);
set(gca,'FontSize',fonts,...
    'XLim',[0 te],...
    'XTick',[0:10:60],...
    'YLim',[-0 50],...
    'YTick',[-10:10:50],...
    'NextPlot','add',...
    'Box','on');
tachs1=[0 te]; tachs2=[0 0];
plot(tachs1,tachs2,'k')
grid off
xlabel('t \rightarrow')
ylabel('u_A (V)  \rightarrow')


sp312=subplot(3,1,2);
set(gca,'FontSize',fonts,...
    'XLim',[0 te],...
    'XTick',[0:10:60],...
    'YLim',[0 210],...
    'YTick',[-150:30:210],...
    'NextPlot','add','Box','on');
tachs1=[0 te]; tachs2=[0 0];
plot(tachs1,tachs2,'k')
grid off
xlabel('t \rightarrow')
ylabel('\omega (rad/s)   \rightarrow')

sp313=subplot(3,1,3);
set(gca,'FontSize',fonts,...
    'XLim',[0 te],...
    'XTick',[0:10:60],...
    'YLim',[-0 500],...
    'YTick',[-100:100:500],...
    'NextPlot','add','Box','on');
tachs1=[0 te]; tachs2=[0 0];
plot(tachs1,tachs2,'k')
grid off
xlabel('t \rightarrow')
ylabel('M_L (Nm)   \rightarrow')


opts=simset('Solver','ode45',...
    'InitialState',[],...
    'MaxStep',.1);
[t,x,y]=sim('s0310',[0 te],opts);

axes(sp311)
plot(t,y(:,2),'k-','linewidth',1.5)

axes(sp312)
plot(t,y(:,1),'k-','linewidth',1.5)    %  omega

axes(sp313)
plot(t,y(:,3),'k-','linewidth',1.5)






















function []=buch(fighandle)
cr0=uimenu('parent', fighandle);
set(cr0,'Label','?')
cr1=uimenu('parent', cr0);
set(cr1,'Label','Mann/Schiffelgen/Froriep')
cr2=uimenu('parent', cr0);
set(cr2,'Label','Einfhrung in die Regelungstechnik')
cr3=uimenu('parent', cr0);
set(cr3,'Label','Hanser-Verlag')

