function m0708
%  m0708.m     (Matlab&Simulink Rel.13 SP1)
%
%  Bild 7.8 a und b
%  Mann/Schiffelgen/Froriep,
%  Einfhrung in die Regelungstechnik, 
%  10.Aufl., Hanser-Verlag, Mnchen, 2005
%  ISBN 3-446-40303-5
%
%  Unterprogramme:  s0706_1.mdl, s0706_2.mdl, 
%                   s0706_3.mdl, s0706_4.mdl
%
%  (c)10.11.05  R.Froriep
%
% ########################################################
%
%  Variations-Empfehlungen:
%
%    Abtastperiode   T     im Bereich  .1   <  T    < .4
%
%  Sprungantwort (Bild 7.8):
%    Sprunghhe   udach  im Bereich .1*pi < udach < .4*pi
%
%  Schwingungsantwort (entsprechend Bild 7.7b):
%    Amplitude    udach  im Bereich .1*pi < udach < .4*pi
%    Kreisfrequenz  om0    im Bereich 10.  < om0  < 40.
%
% ########################################################
clear

     T=.1;           %  Voreinstellung T=.1

     udach=.2*pi;    %  Voreinstellung udach=.2*pi

     om0=20;        %  Voreinstellung 0m0=20

% ########################################################

menu='none';  % none oder fig
close all
fonts=8;


% Fliehkraftpendel-Strecke

% Analoges Modell:
rP=.01;       % Pendelabstand in m
l=.1 ;        % Pendellnge in m
m= .5;        % Masse eines Pendels in kg
cR=5e-2;      % Reibkonstante in Nm/(rad/s)
g=9.81;       % Erdbeschleunigung in m/s^2

c1=cR/(2*m*l^2);  c2=g/l;

% Arbeitspunkt:
phi0=45;       
phi0=(pi/180)*phi0;
omega0=sqrt( 2*g*sin(phi0)/(2*rP*cos(phi0)+l*sin(2*phi0)) );

% Lineares Modell:
a0=omega0^2*((rP/l)*sin(phi0)-cos(2*phi0)) + (g/l)*cos(phi0);
a1=cR/(m*l^2);
b0=omega0*((2*rP/l)*cos(phi0)+sin(2*phi0));


KPS=b0/a0;
wo=sqrt(a0);
d=a1/(2*sqrt(a0));     
zae=[KPS*wo^2]; 
nen=[1 2*d*wo wo^2];


% Digitales Modell:
sig=-wo*d; we=wo*sqrt(1-d^2);
phi=-atan(d/sqrt(1-d^2));

% Formeln gem Buch S.249/250:
b0=0;
b1=KPS*(1/sqrt(1-d^2)*(cos(phi) + exp(sig*T)*cos(phi-we*T)) ...
    - 2*exp(sig*T)*cos(we*T))
b2=KPS*(exp(sig*T)*(exp(sig*T)- 1/sqrt(1-d^2) * cos(phi-we*T)))
a1=-2*exp(sig*T)*cos(we*T)
a2=exp(2*sig*T)

zaed=[b0 b1 b2]; nend=[1  a1  a2];


% In Workspace ablegen (fr Simulink)
assignin('base','T',T)
assignin('base','udach',udach)
assignin('base','om0',om0)
assignin('base','zae',zae)
assignin('base','nen',nen)
assignin('base','zaed',zaed)
assignin('base','nend',nend)


figure(1)
set(gcf,'Units','normal','Position',[.53 .6 .45 .35], ...
    'NumberTitle','off','MenuBar',menu,...
    'Name',' Bild 7.8'); 
buch(gcf)  

te=2; 

opts=simset('Solver','ode45',...
    'InitialState',[0 0],...
    'MaxStep',0.05);

[t1,x1,y1]=sim('s0706_1',[0 te],opts);

opts=simset('Solver','FixedStepDiscrete',...
    'InitialState',[0 0],...
    'FixedStep',T);

[t2,x2,y2]=sim('s0706_2',[0 te],opts);

subplot(2,1,1)
y1(:,1)=y1(:,1)/pi;
plot(t1,y1(:,1),'g')
grid on, hold on
set(gca,'FontSize',fonts,...
    'XTick',[0:.4:te],...
    'YTick',[-.2:.2:.4])
axis([0 te -.1 .5]); 
y2(:,1)=y2(:,1)/pi;
plot(t2,y2(:,1),'bx','LineW', 2)
tachs1=[0 te]; tachs2=[0 0];
plot(tachs1,tachs2,'k')
title('Grn: Analoges Modell, Blau: Digitales Modell')
ylabel('y/\pi')

subplot(2,1,2)
y1(:,2)=(180/pi)*y1(:,2);
y2(:,2)=(180/pi)*y2(:,2);
plot(t1,y1(:,2),'g'), grid on, hold on
set(gca,'FontSize',fonts,...
    'XTick',[0:.4:te],'YTick',[0:4:10]);
axis([0 te -1 10]); 
plot(t2,y2(:,2),'bx','LineW', 2)
tachs1=[0 te]; tachs2=[0 0];
plot(tachs1,tachs2,'k')
ylabel('x')


figure(2)
set(gcf,'Units','normal','Position',[.53 .1 .45 .35], ...
    'NumberTitle','off','MenuBar',menu,...
    'Name',' Zu Bild 7.8: Schwingungsanregung'); 
buch(gcf)  

opts=simset('Solver','ode45',...
    'InitialState',[0 0],...
    'MaxStep',0.005);

[t1,x1,y1]=sim('s0706_3',[0 te],opts);

opts=simset('Solver','FixedStepDiscrete',...
    'InitialState',[0 0],...
    'FixedStep',T);

[t2,x2,y2]=sim('s0706_4',[0 te],opts);

subplot(2,1,1)
y1(:,1)=y1(:,1)/pi;
plot(t1,y1(:,1),'g'),grid on, hold on
set(gca,'FontSize',fonts,...
    'XTick',[0:.4:te],'YTick',[-.4:.2:.4])
axis([0 te -.5 .5]); 
y2(:,1)=y2(:,1)/pi;
plot(t2,y2(:,1),'bx','LineW', 2)
tachs1=[0 te]; tachs2=[0 0];
plot(tachs1,tachs2,'k')
title('Grn: Analoges Modell, Blau: Digitales Modell')
ylabel('y/\pi')

subplot(2,1,2)
y1(:,2)=(180/pi)*y1(:,2);
y2(:,2)=(180/pi)*y2(:,2);
plot(t1,y1(:,2),'g'), grid on, hold on
set(gca,'FontSize',fonts,...
    'XTick',[0:.4:te],'YTick',[-12:4:12])
axis([0 te -10 10]); 
plot(t2,y2(:,2),'bx','LineW', 2)
tachs1=[0 te]; tachs2=[0 0];
plot(tachs1,tachs2,'k')
ylabel('x')




















function []=buch(fighandle)
cr0=uimenu('parent', fighandle);
set(cr0,'Label','?') 
cr1=uimenu('parent', cr0);
set(cr1,'Label','Mann/Schiffelgen/Froriep') 
cr2=uimenu('parent', cr0);
set(cr2,'Label','Einfhrung in die Regelungstechnik') 
cr3=uimenu('parent', cr0);
set(cr3,'Label','Hanser-Verlag')



